module PencilFFTs

import FFTW
import MPI

using LinearAlgebra
using Reexport
using TimerOutputs

include("Permutations/Permutations.jl")
include("Pencils/Pencils.jl")
include("PencilArrays/PencilArrays.jl")
include("PencilIO/PencilIO.jl")
include("Transforms/Transforms.jl")

@reexport using .PencilArrays
@reexport using .PencilIO
@reexport using .Transforms

# For convenience...
import .Transforms: AbstractTransform, FFTReal
import .PencilArrays.Transpositions: AbstractTransposeMethod

export PencilFFTPlan
export allocate_input, allocate_output, get_scale_factor

# Functions to be extended for PencilFFTs types.
import .PencilArrays: get_comm, get_timer

const AbstractTransformList{N} = NTuple{N, AbstractTransform} where N

include("global_fft.jl")
include("pencil_plans.jl")
include("operations.jl")

end # module
